.. currentmodule:: abjad.tools.pitchtools

transpose_pitch_number_by_octave_transposition_mapping
======================================================

.. autofunction:: transpose_pitch_number_by_octave_transposition_mapping
